# Changelog

## v0.0.10 - 27.9.2023

- Make `YRoomClientOptions` picklable.

## v0.0.9 - 27.9.2023

- `YRoomMessage.has_edits: bool` flag indicating data changes have occurred.
- New `YRoomClientOptions`: disallow writes to document or awareness state.
- Always send awareness update after sync step 1.

## v0.0.8
